#
# spec file for package libcss
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%global make_vars COMPONENT_TYPE=lib-shared PREFIX=%{_prefix} LIBDIR=%{_lib} CC=cc Q=
%global build_vars OPTCFLAGS='%{optflags}' OPTLDFLAGS="$RPM_LD_FLAGS"
Name:           libcss
Version:        0.9.2
Release:        1.1
Summary:        A CSS parser and selection engine
License:        MIT
URL:            https://www.netsurf-browser.org/projects/libcss/
Source:         http://download.netsurf-browser.org/libs/releases/%{name}-%{version}-src.tar.gz
Patch0:         libcss-buildopts.patch
Patch1:         fix-test-includes.patch
BuildRequires:  netsurf-buildsystem >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(libparserutils) >= 0.2.0
BuildRequires:  pkgconfig(libwapcaplet) >= 0.2.1

%description
LibCSS is a CSS (Cascading Style Sheet) parser and selection engine,
written in C. It was developed as part of the NetSurf project.

%package -n libcss0
Summary:        A CSS parser and selection engine

%description -n libcss0
LibCSS is a CSS (Cascading Style Sheet) parser and selection engine,
written in C. It was developed as part of the NetSurf project.

Features:
* Parses CSS, good and bad
* Simple C API
* Low memory usage
* Fast selection engine
* Portable

%package devel
Summary:        Development files for %{name}
Requires:       libcss0 = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q
%autopatch -p1

%build
%make_build %{make_vars} %{build_vars}

%install
%make_install %{make_vars}

%check
%make_build test %{make_vars} %{build_vars}

%post -n libcss0 -p /sbin/ldconfig
%postun -n libcss0 -p /sbin/ldconfig

%files -n libcss0
%license COPYING
%{_libdir}/%{name}.so.*

%files devel
%doc docs/*
%doc README
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Oct  7 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 0.9.2:
  * Added support for SVG `fill-opacity` property.
  * Added support for SVG `stroke-opacity` property.
  * Added support for CSS property wide `revert` value.
  * Added support for CSS property wide `unset` value.
  * Added support for CSS property wide `initial` value.
  * Added support for CSS `position` property `sticky` value.
  * Added support for CSS `display` property "grid" values.
  * Added support for `prefers-color-scheme` media query.
  * Added new public API for CSS unit conversion.
  * Added support for predefined counter styles.
  * Optimised media query handling.
  * Made selection code generator deterministic.
  * Various selection code generator improvements.
  * Squashed leak of system font names.
  * Improved internal handling of property units.
  * Improved internal string map.
  * Minor buildsystem improvements.
  * Improved example code.
  * Added new tests.
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Wed Sep  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.1:
  * Many bugfixes around
  * support for new netsurf-buildsystem toolset
- Rebase libcss-buildopts.patch to this release
- Add patch to fix missing inlcudes:
  * fix-test-includes.patch
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM groups.
* Wed Feb  4 2015 p.drouand@gmail.com
- Update to version 0.4.0
  * Due to the change from CSS2 overflow to CSS3 overflow properties, the
  computed style access functions for overflow properties have changed.
  The overflow property is removed.  Added are overflow-x and overflow-y
  properties.  (The overflow shorthand property now sets overflow-x and
  overflow-y.)
  This change affects the following functions:
    Removed from   include/libcss/computed.h    --  css_computed_overflow()
    Added to       include/libcss/computed.h    --  css_computed_overflow_x()
    Added to       include/libcss/computed.h    --  css_computed_overflow_y()
* Fri Oct 31 2014 crrodriguez@opensuse.org
- libcss-buildopts.patch: Do not define BSD_SOURCE but
  GNU_SOURCE (fioxes build fail in factory)
- use -std=gnu99 instead of -std=c99.
- Disable -Werror
* Fri May 23 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
* Fri May 23 2014 fstrba@suse.com
- Initial import of libcss, inspired from Fedora package
